@@ -14,7 +14,6 @@ EXTENSIONS = {
     'bz2': {'binary', 'bzip2'},
     'c': {'text', 'c'},
     'cc': {'text', 'c++'},
-    'cu': {'text', 'cuda'},
     'cfg': {'text'},
     'chs': {'text', 'c2hs'},
     'clj': {'text', 'clojure'},
@@ -31,6 +30,7 @@ EXTENSIONS = {
     'cson': {'text', 'cson'},
     'css': {'text', 'css'},
     'csv': {'text', 'csv'},
+    'cu': {'text', 'cuda'},
     'cxx': {'text', 'c++'},
     'dart': {'text', 'dart'},
     'def': {'text', 'def'},
@@ -130,13 +130,13 @@ EXTENSIONS = {
     'proto': {'text', 'proto'},
     'puml': {'text', 'plantuml'},
     'purs': {'text', 'purescript'},
+    'pxd': {'text', 'cython'},
+    'pxi': {'text', 'cython'},
     'py': {'text', 'python'},
     'pyi': {'text', 'pyi'},
     'pyx': {'text', 'cython'},
     'pyz': {'binary', 'pyz'},
     'pyzw': {'binary', 'pyz'},
-    'pxd': {'text', 'cython'},
-    'pxi': {'text', 'cython'},
     'r': {'text', 'r'},
     'rb': {'text', 'ruby'},
     'rs': {'text', 'rust'},
@@ -146,16 +146,16 @@ EXTENSIONS = {
     'sbt': {'text', 'sbt', 'scala'},
     'sc': {'text', 'scala'},
     'scala': {'text', 'scala'},
-    'scss': {'text', 'scss'},
     'scm': {'text', 'scheme'},
+    'scss': {'text', 'scss'},
     'sh': {'text', 'shell'},
     'sls': {'text', 'salt'},
     'so': {'binary'},
     'sol': {'text', 'solidity'},
     'spec': {'text', 'spec'},
+    'sql': {'text', 'sql'},
     'ss': {'text', 'scheme'},
     'styl': {'text', 'stylus'},
-    'sql': {'text', 'sql'},
     'sv': {'text', 'system-verilog'},
     'svg': {'text', 'image', 'svg', 'xml'},
     'svh': {'text', 'system-verilog'},
@@ -164,12 +164,12 @@ EXTENSIONS = {
     'swiftdeps': {'text', 'swiftdeps'},
     'tac': {'text', 'twisted', 'python'},
     'tar': {'binary', 'tar'},
+    'tf': {'text', 'terraform'},
+    'tfvars': {'text', 'terraform'},
     'tgz': {'binary', 'gzip'},
     'thrift': {'text', 'thrift'},
     'tiff': {'binary', 'image', 'tiff'},
     'toml': {'text', 'toml'},
-    'tf': {'text', 'terraform'},
-    'tfvars': {'text', 'terraform'},
     'ts': {'text', 'ts'},
     'tsx': {'text', 'tsx'},
     'ttf': {'binary', 'ttf'},
@@ -183,12 +183,12 @@ EXTENSIONS = {
     'vue': {'text', 'vue'},
     'war': {'binary', 'zip', 'jar'},
     'wav': {'binary', 'audio', 'wav'},
-    'wkt': {'text', 'wkt'},
     'whl': {'binary', 'wheel', 'zip'},
+    'wkt': {'text', 'wkt'},
     'woff': {'binary', 'woff'},
     'woff2': {'binary', 'woff2'},
     'wsgi': {'text', 'wsgi', 'python'},
-    'xhtml': {'text', 'xml', 'xhtml'},
+    'xhtml': {'text', 'xml', 'html', 'xhtml'},
     'xml': {'text', 'xml'},
     'xq': {'text', 'xquery'},
     'xql': {'text', 'xquery'},
@@ -212,20 +212,20 @@ EXTENSIONS_NEED_BINARY_CHECK = {
 
 NAMES = {
     '.babelrc': EXTENSIONS['json'] | {'babelrc'},
-    '.bashrc': EXTENSIONS['bash'],
     '.bash_aliases': EXTENSIONS['bash'],
     '.bash_profile': EXTENSIONS['bash'],
+    '.bashrc': EXTENSIONS['bash'],
     '.bowerrc': EXTENSIONS['json'] | {'bowerrc'},
     '.coveragerc': EXTENSIONS['ini'] | {'coveragerc'},
     '.cshrc': EXTENSIONS['csh'],
     '.dockerignore': {'text', 'dockerignore'},
     '.editorconfig': {'text', 'editorconfig'},
     '.flake8': EXTENSIONS['ini'] | {'flake8'},
-    '.gitconfig': EXTENSIONS['ini'] | {'gitconfig'},
-    '.hgrc': EXTENSIONS['ini'] | {'hgrc'},
     '.gitattributes': {'text', 'gitattributes'},
+    '.gitconfig': EXTENSIONS['ini'] | {'gitconfig'},
     '.gitignore': {'text', 'gitignore'},
     '.gitmodules': {'text', 'gitmodules'},
+    '.hgrc': EXTENSIONS['ini'] | {'hgrc'},
     '.jshintrc': EXTENSIONS['json'] | {'jshintrc'},
     '.mailmap': {'text', 'mailmap'},
     '.mention-bot': EXTENSIONS['json'] | {'mention-bot'},
@@ -236,8 +236,8 @@ NAMES = {
     '.yamllint': EXTENSIONS['yaml'] | {'yamllint'},
     '.zshrc': EXTENSIONS['zsh'],
     'AUTHORS': EXTENSIONS['txt'],
-    'BUILD.bazel': {'text', 'bazel'},
     'BUILD': {'text', 'bazel'},
+    'BUILD.bazel': {'text', 'bazel'},
     'CMakeLists.txt': EXTENSIONS['cmake'],
     'COPYING': EXTENSIONS['txt'],
     'Dockerfile': {'text', 'dockerfile'},
